@@ -36,6 +36,7 @@
 #include "memberdef.h"
 #include "filename.h"
 #include "membername.h"
+#include "resourcemgr.h"
 
 // file format: (all multi-byte values are stored in big endian format)
 //   4 byte header
@@ -309,7 +310,6 @@ void SearchIndex::write(const char *fileName)
   padding = size - padding;
 
   //int statsOffset = size;
-  QDictIterator<IndexWord> wdi(m_words);
   //IndexWord *iw;
   int *wordStatOffsets = new int[m_words.count()];
   
@@ -444,7 +444,7 @@ SearchIndexExternal::~SearchIndexExternal()
 
 static QCString definitionToName(Definition *ctx)
 {
-  if (ctx->definitionType()==Definition::TypeMember)
+  if (ctx && ctx->definitionType()==Definition::TypeMember)
   {
     MemberDef *md = (MemberDef*)ctx;
     if (md->isFunction())
@@ -583,9 +583,9 @@ void SearchIndexExternal::write(const char *fileName)
 #include "doxygen.h"
 #include "message.h"
 
-static const char search_script[]=
-#include "search.js.h"
-;
+//static const char search_script[]=
+//#include "search.js.h"
+//;
 
 #define SEARCH_INDEX_ALL         0
 #define SEARCH_INDEX_CLASSES     1
@@ -1076,7 +1076,6 @@ void writeJavascriptSearchIndex()
         for (li.toFirst();(dl=li.current());++li)
         {
           Definition *d = dl->getFirst();
-          QCString id = d->localName();
 
           if (!firstEntry)
           {
@@ -1265,15 +1264,10 @@ void writeJavascriptSearchIndex()
   }
 
   {
-    QFile f(searchDirName+"/search.js");
+    QFile f(searchDirName+"/searchdata.js");
     if (f.open(IO_WriteOnly))
     {
       FTextStream t(&f);
-      t << "// Search script generated by doxygen" << endl;
-      t << "// Copyright (C) 2009 by Dimitri van Heesch." << endl << endl;
-      t << "// The code in this file is loosly based on main.js, part of Natural Docs," << endl;
-      t << "// which is Copyright (C) 2003-2008 Greg Valure" << endl;
-      t << "// Natural Docs is licensed under the GPL." << endl << endl;
       t << "var indexSectionsWithContent =" << endl;
       t << "{" << endl;
       bool first=TRUE;
@@ -1314,8 +1308,25 @@ void writeJavascriptSearchIndex()
       }
       if (!first) t << "\n";
       t << "};" << endl << endl;
-      t << search_script;
+      t << "var indexSectionLabels =" << endl;
+      t << "{" << endl;
+      first=TRUE;
+      static SearchIndexCategoryMapping map;
+      j=0;
+      for (i=0;i<NUM_SEARCH_INDICES;i++)
+      {
+        if (g_searchIndexCount[i]>0)
+        {
+          if (!first) t << "," << endl;
+          t << "  " << j << ": \"" << convertToXML(map.categoryLabel[i]) << "\"";
+          first=FALSE;
+          j++;
+        }
+      }
+      if (!first) t << "\n";
+      t << "};" << endl << endl;
     }
+    ResourceMgr::instance().copyResource("search.js",searchDirName);
   }
   {
     QFile f(searchDirName+"/nomatches.html");
@@ -1341,24 +1352,6 @@ void writeJavascriptSearchIndex()
   Doxygen::indexList->addStyleSheetFile("search/search.js");
 }
 
-void writeSearchCategories(FTextStream &t)
-{
-  static SearchIndexCategoryMapping map;
-  int i,j=0;
-  for (i=0;i<NUM_SEARCH_INDICES;i++)
-  {
-    if (g_searchIndexCount[i]>0)
-    {
-      t << "<a class=\"SelectItem\" href=\"javascript:void(0)\" "
-        << "onclick=\"searchBox.OnSelectItem(" << j << ")\">"
-        << "<span class=\"SelectionMark\">&#160;</span>"
-        << convertToXML(map.categoryLabel[i])
-        << "</a>";
-      j++;
-    }
-  }
-}
-
 //---------------------------------------------------------------------------------------------
 
 void initSearchIndexer()
